@@ -1,6 +1,6 @@
 /*
  *  XMMS Crossfade Plugin
- *  Copyright (C) 2000-2004  Peter Eisenlohr <peter@eisenlohr.org>
+ *  Copyright (C) 2000-2005  Peter Eisenlohr <peter@eisenlohr.org>
  *
  *  based on the original OSS Output Plugin
  *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
@@ -28,10 +28,16 @@
 #include "crossfade.h"
 
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
+#ifdef HAVE_GTK_2_0
+#  include "interface-2.0.h"
+#  include "support-2.0.h"
+#else
+#  include "interface.h"
+#  include "support.h"
+#endif
 
-void on_help_close_button_clicked(GtkButton *button, gpointer user_data)
+void
+on_help_close_button_clicked(GtkButton * button, gpointer user_data)
 {
 
 }
