@@ -1,6 +1,6 @@
 /*
  *  XMMS Crossfade Plugin
- *  Copyright (C) 2000-2004  Peter Eisenlohr <peter@eisenlohr.org>
+ *  Copyright (C) 2000-2005  Peter Eisenlohr <peter@eisenlohr.org>
  *
  *  based on the original OSS Output Plugin
  *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
@@ -33,16 +33,13 @@
 
 typedef struct
 {
-  gpointer       data;
-  gint           size;
+	gpointer data;
+	gint size;
 }
 convert_context_t;
 
-void convert_init(convert_context_t *cc);
-gint convert_flow(convert_context_t *cc,
-		  gpointer          *buffer,
-		  gint               length,
-		  format_t          *format);
-void convert_free(convert_context_t *cc);
+void convert_init(convert_context_t * cc);
+gint convert_flow(convert_context_t * cc, gpointer * buffer, gint length, format_t * format);
+void convert_free(convert_context_t * cc);
 
-#endif  /* _CONVERT_H_ */
+#endif /* _CONVERT_H_ */
