@@ -1,6 +1,6 @@
 /* 
  *  XMMS Crossfade Plugin
- *  Copyright (C) 2000-2004  Peter Eisenlohr <peter@eisenlohr.org>
+ *  Copyright (C) 2000-2005  Peter Eisenlohr <peter@eisenlohr.org>
  *
  *  based on the original OSS Output Plugin
  *  Copyright (C) 1998-2000  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
@@ -32,10 +32,24 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#include <xmms/plugin.h>
-#include <xmms/xmmsctrl.h>
-#include <xmms/configfile.h>
-#include <xmms/util.h>
+#ifdef COMPILE_FOR_XMMS
+#  include <xmms/plugin.h>
+#  include <xmms/xmmsctrl.h>
+#  include <xmms/configfile.h>
+#  include <xmms/util.h>
+#endif
+#ifdef COMPILE_FOR_BMP
+#  include <bmp/plugin.h>
+#  include <bmp/beepctrl.h>
+#  include <bmp/configfile.h>
+#  include <bmp/util.h>
+#endif
+#ifdef COMPILE_FOR_AUDACIOUS
+#  include <audacious/plugin.h>
+#  include <audacious/beepctrl.h>
+#  include <audacious/configfile.h>
+#  include <audacious/util.h>
+#endif
 
 #include "debug.h"
 
@@ -125,6 +139,7 @@
 #define CONFIG_DEFAULT							\
 { 0,                            /* output_method */			\
   44100,                        /* output_rate */			\
+  2,                            /* output_quality */			\
   0,                            /* oss_audio_device */			\
   FALSE,                        /* oss_use_alt_audio_device */		\
   NULL,                         /* oss_alt_audio_device */		\
@@ -321,8 +336,8 @@
 }
 
 
-#define DEBUG(x)  {if(config->enable_debug) debug x;}
-#define PERROR(x) {if(config->enable_debug) perror(x);}
+#define DEBUG(x)  { if (config->enable_debug) debug x; }
+#define PERROR(x) { if (config->enable_debug) perror(x); }
 
 #define WRAP(x,n) (((x)<0)?((n)-(x))%(n):((x)%(n)))
 #define B2MS(x)   ((gint)((gint64)(x)*1000/OUTPUT_BPS))
@@ -333,13 +348,14 @@
 OutputPlugin *get_oplugin_info();
 OutputPlugin *get_crossfade_oplugin_info();
 
-/* xmms internal prototypes */ /* XMMS */
-gint     ctrlsocket_get_session_id();
+/* xmms internal prototypes */
+/* XMMS */
+gint ctrlsocket_get_session_id();
 gboolean get_input_playing();
-GList   *get_output_list();
-GList   *get_effect_list();
-gint     get_playlist_position();
-gint     playlist_get_current_length();
+GList *get_output_list();
+GList *get_effect_list();
+gint get_playlist_position();
+gint playlist_get_current_length();
 #ifdef HAVE_PLAYLIST_GET_FILENAME
 gchar *playlist_get_filename(gint pos);
 #endif
@@ -351,191 +367,190 @@ void xfade_realize_ep_config();
 
 typedef struct
 {
-  gint mix_size;        /* mixing buffer length */
-  gint sync_size;       /* additional buffer space for mix timing */
-  gint preload_size;    /* preload buffer length */
+	gint mix_size;		/* mixing buffer length */
+	gint sync_size;		/* additional buffer space for mix timing */
+	gint preload_size;	/* preload buffer length */
 
-  /* ---------------------------------------------------------------------- */
+	/* ---------------------------------------------------------------------- */
 
-  gpointer data;        /* buffer */
-  gint     size;        /* total buffer length */
+	gpointer data;		/* buffer */
+	gint size;		/* total buffer length */
 
-  /* ---------------------------------------------------------------------- */
+	/* ---------------------------------------------------------------------- */
 
-  gint   used;          /* length */
-  gint   rd_index;      /* offset */
+	gint used;		/* length */
+	gint rd_index;		/* offset */
 
-  gint   preload;       /* > 0: preloading */
+	gint preload;		/* > 0: preloading */
 
-  /* ---------------------------------------------------------------------- */
+	/* ---------------------------------------------------------------------- */
 
-  gint   mix;           /* > 0: mixing new data into buffer */
+	gint mix;		/* > 0: mixing new data into buffer */
 
-  gint   fade;          /* > 0: fading in new data */
-  gint   fade_len;      /* length of fadein */
-  gfloat fade_scale;    /* 1.0f - in_level */
+	gint fade;		/* > 0: fading in new data */
+	gint fade_len;		/* length of fadein */
+	gfloat fade_scale;	/* 1.0f - in_level */
 
 #define GAP_SKIPPING_POSITIVE -1
 #define GAP_SKIPPING_NEGATIVE -2
 #define GAP_SKIPPING_DONE     -3
-  gint   gap;           /* > 0: removing (leading) gap */
-  gint   gap_len;       /* max. len of gap, 0=disabled */
-  gint   gap_level;     /* max. sample value+1 to be considered "silent" */
-  gint   gap_killed;    /* number of bytes that were killed last time */
-  gint   gap_skipped;   /* negative/positive samples skipped */
+	gint gap;		/* > 0: removing (leading) gap */
+	gint gap_len;		/* max. len of gap, 0=disabled */
+	gint gap_level;		/* max. sample value+1 to be considered "silent" */
+	gint gap_killed;	/* number of bytes that were killed last time */
+	gint gap_skipped;	/* negative/positive samples skipped */
 
-  /* ---------------------------------------------------------------------- */
+	/* ---------------------------------------------------------------------- */
 
-  gint   silence;       /* > 0: delay until start of silence */
-  gint   silence_len;   /* > 0: inserting silence */
+	gint silence;		/* > 0: delay until start of silence */
+	gint silence_len;	/* > 0: inserting silence */
 
-  gint     reopen;      /* >= 0: countdown to reopen device (disk_writer hack) */
-  gboolean reopen_sync; /* TRUE: sync output plugin before reopening */
+	gint reopen;		/* >= 0: countdown to reopen device (disk_writer hack) */
+	gboolean reopen_sync;	/* TRUE: sync output plugin before reopening */
 
-  gint     pause;       /* >= 0: countdown to pause output plugin */
+	gint pause;		/* >= 0: countdown to pause output plugin */
 }
 buffer_t;
 
 typedef struct
 {
-  gint     config;              // one of FADE_CONFIG_*, constant
-  gint     type;                // one of FADE_TYPE_*
+	gint config;		// one of FADE_CONFIG_*, constant
+	gint type;		// one of FADE_TYPE_*
 
-  gint     pause_len_ms;        // PAUSE
+	gint pause_len_ms;	// PAUSE
 
-  gint     simple_len_ms;       // SIMPLE_XF
+	gint simple_len_ms;	// SIMPLE_XF
 
-  gboolean out_enable;          // ADVANCED_XF
-  gint     out_len_ms;          // ADVANCED_XF, FADEOUT, PAUSE
-  gint     out_volume;          // ADVANCED_XF, FADEOUT
+	gboolean out_enable;	// ADVANCED_XF
+	gint out_len_ms;	// ADVANCED_XF, FADEOUT, PAUSE
+	gint out_volume;	// ADVANCED_XF, FADEOUT
 
-  gint     ofs_type;            // ADVANCED_XF
-  gint     ofs_type_wanted;     // ADVANCED_XF
-  gint     ofs_custom_ms;       // ADVANCED_XF, FADEOUT (additional silence), PAUSE
+	gint ofs_type;		// ADVANCED_XF
+	gint ofs_type_wanted;	// ADVANCED_XF
+	gint ofs_custom_ms;	// ADVANCED_XF, FADEOUT (additional silence), PAUSE
 
-  gboolean in_locked;           // ADVANCED_XF
-  gboolean in_enable;           // ADVANCED_XF, FLUSH
-  gint     in_len_ms;           // ADVANCED_XF, FLUSH, FADEIN, PAUSE
-  gint     in_volume;           // ADVANCED_XF, FLUSH, FADEIN
+	gboolean in_locked;	// ADVANCED_XF
+	gboolean in_enable;	// ADVANCED_XF, FLUSH
+	gint in_len_ms;		// ADVANCED_XF, FLUSH, FADEIN, PAUSE
+	gint in_volume;		// ADVANCED_XF, FLUSH, FADEIN
 
-  gboolean flush_pause_enable;  // FLUSH
-  gint     flush_pause_len_ms;  // FLUSH
-  gboolean flush_in_enable;     // FLUSH
-  gint     flush_in_len_ms;     // FLUSH
-  gint     flush_in_volume;     // FLUSH
+	gboolean flush_pause_enable;	// FLUSH
+	gint flush_pause_len_ms;	// FLUSH
+	gboolean flush_in_enable;	// FLUSH
+	gint flush_in_len_ms;	// FLUSH
+	gint flush_in_volume;	// FLUSH
 
-  /* additional stuff which is not configureable by the user */
-  gboolean flush;               // TRUE for manual, FALSE for xfade config
-  guint32  type_mask;           // bitmask for FADE_TYPEs
+	/* additional stuff which is not configureable by the user */
+	gboolean flush;		// TRUE for manual, FALSE for xfade config
+	guint32 type_mask;	// bitmask for FADE_TYPEs
 }
 fade_config_t;
 
 typedef struct
 {
-  gboolean  throttle_enable;
-  gboolean  max_write_enable;
-  gint      max_write_len;
-  gboolean  force_reopen;
+	gboolean throttle_enable;
+	gboolean max_write_enable;
+	gint max_write_len;
+	gboolean force_reopen;
 }
 plugin_config_t;
 
 typedef struct
 {
-  /* output method */
-  gint output_method;
-  gint output_rate;
+	/* output: method */
+	gint output_method;
+	gint output_rate;
+	gint output_quality;
 
-  /* output method: builtin OSS */
-  gint     oss_audio_device;
-  gboolean oss_use_alt_audio_device;
-  gchar   *oss_alt_audio_device;
+	/* output: builtin OSS */
+	gint oss_audio_device;
+	gboolean oss_use_alt_audio_device;
+	gchar *oss_alt_audio_device;
 
-  gint     oss_mixer_device;
-  gboolean oss_use_alt_mixer_device;
-  gchar   *oss_alt_mixer_device;
-  gboolean oss_mixer_use_master;
+	gint oss_mixer_device;
+	gboolean oss_use_alt_mixer_device;
+	gchar *oss_alt_mixer_device;
+	gboolean oss_mixer_use_master;
 
-  gint     oss_buffer_size_ms;
-  gint     oss_preload_size_ms;
+	gint oss_buffer_size_ms;
+	gint oss_preload_size_ms;
 
-  gint     oss_fragments;
-  gint     oss_fragment_size;
-  gboolean oss_maxbuf_enable;
+	gint oss_fragments;
+	gint oss_fragment_size;
+	gboolean oss_maxbuf_enable;
 
-  /* output method: plugin */
-  gchar   *op_config_string;  /* stores configs for all plugins */
-  gchar   *op_name;           /* name of the current plugin */
+	/* output: plugin */
+	gchar *op_config_string;	/* stores configs for all plugins */
+	gchar *op_name;		/* name of the current plugin */
 
-  /* effects */
-  gchar   *ep_name;
-  gboolean ep_enable;
-  gboolean volnorm_enable;
-  gboolean volnorm_use_qa;
-  gint     volnorm_target;
+	/* effects */
+	gchar *ep_name;
+	gboolean ep_enable;
+	gboolean volnorm_enable;
+	gboolean volnorm_use_qa;
+	gint volnorm_target;
 
-  /* crossfader */
-  gint          mix_size_ms;
-  gboolean      mix_size_auto;
-  fade_config_t fc[MAX_FADE_CONFIGS];
+	/* crossfader */
+	gint mix_size_ms;
+	gboolean mix_size_auto;
+	fade_config_t fc[MAX_FADE_CONFIGS];
 
-  /* gap killer */
-  gboolean gap_lead_enable;
-  gint     gap_lead_len_ms;
-  gint     gap_lead_level;
+	/* gap killer */
+	gboolean gap_lead_enable;
+	gint gap_lead_len_ms;
+	gint gap_lead_level;
 
-  gboolean gap_trail_enable;
-  gint     gap_trail_len_ms;
-  gint     gap_trail_level;
-  gboolean gap_trail_locked;
+	gboolean gap_trail_enable;
+	gint gap_trail_len_ms;
+	gint gap_trail_level;
+	gboolean gap_trail_locked;
 
-  gboolean gap_crossing;
+	gboolean gap_crossing;
 
-  /* misc */
-  gboolean enable_debug;
-  gboolean enable_monitor;
+	/* misc */
+	gboolean enable_debug;
+	gboolean enable_monitor;
 
-  gboolean enable_mixer;
-  gboolean mixer_reverse;
-  gboolean mixer_software;
-  gint     mixer_vol_left;
-  gint     mixer_vol_right;
+	gboolean enable_mixer;
+	gboolean mixer_reverse;
+	gboolean mixer_software;
+	gint mixer_vol_left;
+	gint mixer_vol_right;
 
-  gint     songchange_timeout;
-  gint     preload_size_ms;
-  gboolean album_detection;
-  gboolean no_xfade_if_same_file;
-  gboolean enable_http_workaround;
-  gboolean enable_op_max_used;
-  gint     op_max_used_ms;
-  gboolean output_keep_opened;
+	gint songchange_timeout;
+	gint preload_size_ms;
+	gboolean album_detection;
+	gboolean no_xfade_if_same_file;
+	gboolean enable_http_workaround;
+	gboolean enable_op_max_used;
+	gint op_max_used_ms;
+	gboolean output_keep_opened;
 
-  /* presets */
-  GList   *presets;
+	/* presets */
+	GList *presets;
 
-  /* additional stuff which is not configureable by the user */
-  gint     sync_size_ms;
+	/* additional stuff which is not configureable by the user */
+	gint sync_size_ms;
 
-  /* additional stuff which is not saved to the config file */
-  gint     page;
-  gint     oss_page;
-  gint     xf_index;
+	/* additional stuff which is not saved to the config file */
+	gint page;
+	gint oss_page;
+	gint xf_index;
 }
 config_t;
 
 
 /* some global vars... we should really get rid of those somehow */
 extern config_t *config;
-extern config_t  config_default;
+extern config_t config_default;
 extern buffer_t *buffer;
 
-extern pthread_mutex_t buffer_mutex;
-
-extern gboolean opened;         /* XMMS-crossfade is opened */
-extern gboolean output_opened;  /* the output plugin is opened */
+extern gboolean opened;		/* XMMS-crossfade is opened */
+extern gboolean output_opened;	/* the output plugin is opened */
 extern gint     output_offset;
 extern gint64   output_streampos;
 
 extern OutputPlugin *the_op;
-extern gint          the_rate;
+extern gint the_rate;
 
-#endif  /* _CROSSFADE_H_ */
+#endif /* _CROSSFADE_H_ */
